. Copyright 2013-2016 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.ui
-------------------

.. automodule:: reahl.web.ui


Widgets for constructing a page
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

HTML5Page
"""""""""

.. autoclass:: HTML5Page
   :members:

Slot
""""

.. autoclass:: Slot
   :members:

RunningOnBadge
""""""""""""""

.. autoclass:: RunningOnBadge
   :members:

LiteralHTML
"""""""""""

.. autoclass:: LiteralHTML
   :members:

      
Very low-level Widgets that correspond to HTML 
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

HTMLElement
"""""""""""

.. autoclass:: HTMLElement
   :members:

TextNode
""""""""

.. autoclass:: TextNode 
   :members:

Title
"""""

.. autoclass:: Title
   :members:

Link
""""

.. autoclass:: Link
   :members:

Head
""""

.. autoclass:: Head
   :members:

Body
""""

.. autoclass:: Body
   :members:

Span
""""

.. autoclass:: Span
   :members:

More commonly used Widgets that correspond to HTML 
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

A
"

.. autoclass:: A
   :members:

H
"

.. autoclass:: H
   :members:

P
"

.. autoclass:: P
   :members:
  
Div
"""

.. autoclass:: Div
   :members:
  
Nav
"""

.. autoclass:: Nav
   :members:

Article
"""""""

.. autoclass:: Article
   :members:

Header
""""""

.. autoclass:: Header
   :members:

Footer
""""""

.. autoclass:: Footer
   :members:

Li
""

.. autoclass:: Li
   :members:

Ul
""

.. autoclass:: Ul
   :members:

Ol
""

.. autoclass:: Ol
   :members:

Img
"""

.. autoclass:: Img
   :members:


Widgets for Input
^^^^^^^^^^^^^^^^^

.. uml:: ../../../reahl-web/reahl/web_dev/inputandvalidation/form_inputs_and_fields.puml

Form
""""

.. autoclass:: Form
   :members:

FormLayout
""""""""""

.. autoclass:: FormLayout
   :members:

NestedForm
""""""""""

.. autoclass:: NestedForm
   :members:

FieldSet
""""""""

.. autoclass:: FieldSet
   :members:

Legend
""""""

.. autoclass:: Legend
   :members:

Input
"""""

.. autoclass:: Input
   :members:

PrimitiveInput
""""""""""""""

.. autoclass:: PrimitiveInput
   :members:

TextArea
""""""""

.. autoclass:: TextArea
   :members:


SelectInput
"""""""""""

.. autoclass:: SelectInput
   :members:
   

RadioButtonSelectInput
""""""""""""""""""""""

.. autoclass:: RadioButtonSelectInput
   :members:
   
TextInput
"""""""""

.. autoclass:: TextInput
   :members:

PasswordInput
"""""""""""""

.. autoclass:: PasswordInput
   :members:

CheckboxInput
"""""""""""""

.. autoclass:: CheckboxInput
   :members:

CheckboxSelectInput
"""""""""""""""""""

.. autoclass:: CheckboxSelectInput
   :members:
   
ButtonInput
"""""""""""

.. autoclass:: ButtonInput
   :members:
   

Label
"""""

.. autoclass:: Label
   :members:


Tables
^^^^^^

Table
"""""
.. sidebar:: Examples

   - tutorial.table

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>


.. autoclass:: Table
   :members:


DynamicColumn
"""""""""""""

.. autoclass:: DynamicColumn
   :members:

StaticColumn
""""""""""""

.. autoclass:: StaticColumn
   :members:


Caption
"""""""

.. autoclass:: Caption
   :members:

Thead
"""""

.. autoclass:: Thead
   :members:

Tfoot
"""""

.. autoclass:: Tfoot
   :members:

Tbody
"""""

.. autoclass:: Tbody
   :members:

Tr
""

.. autoclass:: Tr
   :members:

Td
""

.. autoclass:: Td
   :members:

Th
""

.. autoclass:: Th
   :members:


Uploading of files
^^^^^^^^^^^^^^^^^^

SimpleFileInput
"""""""""""""""

.. autoclass:: SimpleFileInput
   :members:



Widgets related to Reahl implementation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

HTMLWidget
""""""""""

.. autoclass:: HTMLWidget
   :members:
